@@ -28,7 +28,7 @@ from hspylib.modules.cli.vt100.terminal import Terminal
 
 
 class WidgetFree(Widget):
-    """HSPyLib to Report current system memory usage"""
+    """HSPyLib Widget to Report current system memory usage"""
     WIDGET_ICON = WidgetIcons.DATABASE
     WIDGET_NAME = "Free"
     TOOLTIP = "Report system memory usage."
