@@ -31,10 +31,10 @@ class ExitCode(Enumeration):
     # Returned when something that was supposed to work and failed due to unexpected software behaviour
     FAILED  = 1
 
-    # Additional exit codes can be defined here {
-    # }
-
     # @formatter:on
 
     def __str__(self):
-        return f"{self.name}({self.value})"
+        return "{}{}({})".format(
+            '\033[0;32m' if self.name == 'SUCCESS' else '\033[0;31m',
+            self.name, self.value
+        )
