@@ -3,7 +3,7 @@
 
 """
    @project: HSPyLib
-   @package: hspylib.main.hspylib.modules.qt.promotions
+   @package: main.modules.qt.promotions
       @file: hconsole.py
    @created: Wed, 30 Jun 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -16,8 +16,8 @@
 from typing import Optional
 
 from PyQt5.QtCore import Qt
-from PyQt5.QtGui import QFont, QColor, QTextCursor, QCursor
-from PyQt5.QtWidgets import QWidget, QTextBrowser
+from PyQt5.QtGui import QColor, QCursor, QFont, QTextCursor
+from PyQt5.QtWidgets import QTextBrowser, QWidget
 
 
 class HConsole(QTextBrowser):
