@@ -17,7 +17,7 @@ from abc import abstractmethod
 
 from PyQt5 import uic
 
-from modules.qt.views.qt_view import QtView
+from hspylib.modules.qt.views.qt_view import QtView
 
 
 class MainView(QtView):
